==> remind_05.03.02.orig.tar.gz: remind-05.03.02/README.md <==
# REMIND

Remind is a full-featured calendar/alarm program.  Copying policy is
in the file "COPYRIGHT" included with the source; Remind is licensed under
the GNU General Public License, Vesion 2.

## Prerequisites:

remind and rem2ps have no prerequisites beyond the standard C library and
the standard math library.

rem2html requires the JSON::MaybeXS Perl module and rem2pdf
requires the JSON::MaybeXS, Pango and Cairo Perl modules.

- On Debian-like systems, these prerequisites may be installed with:

    `apt install libjson-maybexs-perl libpango-perl libcairo-perl`

- On RPM-based systems, you need `perl-Pango`, `perl-Cairo` and
  `perl-JSON-MaybeXS`

- On Gentoo, you need `dev-perl/Pango`, `dev-perl/Cairo` and
  `dev-perl/JSON-MaybeXS`.

- On Arch linux, you need `pango-perl`, `cairo-perl` and `perl-json-maybexs`

TkRemind requires Tcl/Tk and the tcllib library.

- On Debian-like systems, install with:

    `apt install tcl tk tcllib`

- On RPM-based systems, you need `tcl`, `tk` and `tcllib`

- On Arch Linux, you need `tk` and `tcllib`.  The latter is available at
  https://aur.archlinux.org/packages/tcllib

If the little arrows for "Previous Month" and "Next Month" do not display
correctly in TkRemind, you may need to install the Noto Fonts.  Install
all of your distribution's Nonto Font-related packages.

- On Debian-like systems, install with:

    `apt install fonts-noto-core fonts-noto-color-emoji fonts-noto-extra fonts-noto-ui-core fonts-noto-ui-extra`

## Installation

Remind can be installed with the usual:

`./configure && make && make test && sudo make install`

You can edit custom.h to configure some aspects of Remind.  Or, if
you have Tcl/Tk installed, you can use the graphical build tool to
edit custom.h on your behalf:

`wish ./build.tk`

---

Contact info: dianne@skoll.ca

Home page:    [https://dianne.skoll.ca/projects/remind/](https://dianne.skoll.ca/projects/remind/)

==> remind_05.03.07.orig.tar.gz: remind-05.03.07/README.md <==
# REMIND

Remind is a full-featured calendar/alarm program.  Copying policy is
in the file "COPYRIGHT" included with the source; Remind is licensed under
the GNU General Public License, Vesion 2.

## Prerequisites:

remind and rem2ps have no prerequisites beyond the standard C library and
the standard math library.

rem2html requires the JSON::MaybeXS Perl module and rem2pdf
requires the JSON::MaybeXS, Pango and Cairo Perl modules.

- On Debian-like systems, these prerequisites may be installed with:

    `apt install libjson-maybexs-perl libpango-perl libcairo-perl`

- On RPM-based systems, you need `perl-Pango`, `perl-Cairo` and
  `perl-JSON-MaybeXS`

- On Gentoo, you need `dev-perl/Pango`, `dev-perl/Cairo` and
  `dev-perl/JSON-MaybeXS`.

- On Arch linux, you need `pango-perl`, `cairo-perl` and `perl-json-maybexs`

TkRemind requires Tcl/Tk and the tcllib library.

- On Debian-like systems, install with:

    `apt install tcl tk tcllib`

- On RPM-based systems, you need `tcl`, `tk` and `tcllib`

- On Arch Linux, you need `tk` and `tcllib`.  The latter is available at
  https://aur.archlinux.org/packages/tcllib

If the little arrows for "Previous Month" and "Next Month" do not display
correctly in TkRemind, you may need to install the Noto Fonts.  Install
all of your distribution's Noto Font-related packages.

- On Debian-like systems, install with:

    `apt install fonts-noto-core fonts-noto-color-emoji fonts-noto-extra fonts-noto-ui-core fonts-noto-ui-extra`

## Installation

Remind can be installed with the usual:

`./configure && make && make test && sudo make install`

You can edit custom.h to configure some aspects of Remind.  Or, if
you have Tcl/Tk installed, you can use the graphical build tool to
edit custom.h on your behalf:

`wish ./build.tk`

---

Contact info: dianne@skoll.ca

Home page:    [https://dianne.skoll.ca/projects/remind/](https://dianne.skoll.ca/projects/remind/)
